︠6a296116-b9ee-42ab-a1ab-5d0349ce8798i︠
%md

# Using CoCalc to Look at National Weather Service Hourly Forecast

A short demo written as the first blizzard of the season arrived in Chicago.

Here's a picture from the NW suburbs the next morning.

<img src="snow_20181126_095249.jpg" width="20%">

## References

- NWS
  - [hourly weather graphs](https://www.weather.gov/wrn/hourly-weather-graph)
  - [REST interface](https://graphical.weather.gov/xml/rest.php)

- Python package noaa-sdk
  - [noaa-sdk on pypi](https://pypi.org/project/noaa-sdk/)
  - [noaa-sdk on github](https://github.com/rconradharris/python-noaa)

- Chicago area blizzard forecast in the news, evening of 2018-11-25
  - [Chicago Sun-Times]()https://chicago.suntimes.com/news/nws-issues-winter-storm-watch-for-sunday-more-than-6-inches-snow-possible/)
  - [Daily Herald](https://www.dailyherald.com/news/20181125/winter-weather-already-causing-headaches-for-travelers-worse-to-come)

## Package note

*The following step is no longer needed. As of 2018-11-28, noaa-sdk is globally installed on CoCalc.*

If `noaa_sdk` isn't available globally in CoCalc yet, open a .term and do
the following. Then restart your worksheet.

```
pip3 install --user noaa_sdk
```

︡c8ae52f0-f698-433a-8dcf-dabaff01f9d0︡{"done":true,"md":"\n# Using CoCalc to Look at National Weather Service Hourly Forecast\n\nA short demo written as the first blizzard of the season arrived in Chicago.\n\nHere's a picture from the NW suburbs the next morning.\n\n<img src=\"snow_20181126_095249.jpg\" width=\"20%\">\n\n## References\n\n- NWS\n  - [hourly weather graphs](https://www.weather.gov/wrn/hourly-weather-graph)\n  - [REST interface](https://graphical.weather.gov/xml/rest.php)\n\n- Python package noaa-sdk\n  - [noaa-sdk on pypi](https://pypi.org/project/noaa-sdk/)\n  - [noaa-sdk on github](https://github.com/rconradharris/python-noaa)\n\n- Chicago area blizzard forecast in the news, evening of 2018-11-25\n  - [Chicago Sun-Times]()https://chicago.suntimes.com/news/nws-issues-winter-storm-watch-for-sunday-more-than-6-inches-snow-possible/)\n  - [Daily Herald](https://www.dailyherald.com/news/20181125/winter-weather-already-causing-headaches-for-travelers-worse-to-come)\n\n## Package note\n\n*The following step is no longer needed. As of 2018-11-28, noaa-sdk is globally installed on CoCalc.*\n\nIf `noaa_sdk` isn't available globally in CoCalc yet, open a .term and do\nthe following. Then restart your worksheet.\n\n```\npip3 install --user noaa_sdk\n```"}
︠08519886-5724-4f81-b50d-8ce2bd11aef8s︠
%auto
%default_mode python3
︡42dc4997-62bc-44db-a601-b38d8a4c15d9︡{"done":true}︡
︠85503d72-b2fb-4e1d-8068-1fd40577cbf6s︠
my_zip_code = '60004'
︡716b916f-d6c9-425b-a829-42ad64c9f722︡{"done":true}︡
︠7d75fc13-125c-4b83-974d-cfaec8cf2fdes︠
from noaa_sdk import noaa
n = noaa.NOAA()
︡171cffb8-95e0-4d00-aa02-2f0e6f976161︡{"done":true}︡
︠66a84b6c-de2d-451e-be03-8c9e951dfaefs︠
# get hourly forecast for next 48 hours
res = n.get_forecasts(postal_code=my_zip_code, country='US', hourly=True)[:48]

# display first three rows of data from NWS
print(res[:3])
︡33cbefea-6259-4724-90eb-ccfb21c346ed︡{"stdout":"[{'number': 1, 'name': '', 'startTime': '2018-11-26T15:00:00-06:00', 'endTime': '2018-11-26T16:00:00-06:00', 'isDaytime': True, 'temperature': 28, 'temperatureUnit': 'F', 'temperatureTrend': None, 'windSpeed': '15 mph', 'windDirection': 'NW', 'icon': 'https://api.weather.gov/icons/land/day/bkn?size=small', 'shortForecast': 'Mostly Cloudy', 'detailedForecast': ''}, {'number': 2, 'name': '', 'startTime': '2018-11-26T16:00:00-06:00', 'endTime': '2018-11-26T17:00:00-06:00', 'isDaytime': True, 'temperature': 26, 'temperatureUnit': 'F', 'temperatureTrend': None, 'windSpeed': '15 mph', 'windDirection': 'WNW', 'icon': 'https://api.weather.gov/icons/land/day/bkn?size=small', 'shortForecast': 'Mostly Cloudy', 'detailedForecast': ''}, {'number': 3, 'name': '', 'startTime': '2018-11-26T17:00:00-06:00', 'endTime': '2018-11-26T18:00:00-06:00', 'isDaytime': True, 'temperature': 24, 'temperatureUnit': 'F', 'temperatureTrend': None, 'windSpeed': '15 mph', 'windDirection': 'WNW', 'icon': 'https://api.weather.gov/icons/land/day/bkn?size=small', 'shortForecast': 'Mostly Cloudy', 'detailedForecast': ''}]\n"}︡{"done":true}︡
︠5a5457a9-3697-4839-93b8-11f943c5c753s︠
# get ready to use dataframes
import pandas as pd
︡23e3666f-226f-4911-bb18-2434dcfcc393︡{"done":true}︡
︠bba428a1-c706-4ce7-ab14-195202623c0cs︠
# convert short forecast wording to numeric level
# only order matters: 0, 1, 2
def snow_number(s):
    if 'Heavy Snow' in s:
        ret = 2
    elif 'Snow' in s:
        ret = 1
    else:
        ret = 0
    return ret
︡16094cd3-db98-4da7-9d5c-30a1c00f0bba︡{"done":true}︡
︠98d936de-ee14-4842-b2de-e4170bb6f705s︠
# put NWS data into a pandas dataframe
df = pd.DataFrame(res)[['startTime','temperature','shortForecast']]
# fix types
df['Time'] = pd.to_datetime(df['startTime'])
df['Snowfall'] = df['shortForecast'].apply(snow_number)
df = df.set_index('Time')
df.head()
︡bc5464d2-aa61-4bd9-a5a1-47d5b6f7a6c1︡{"html":"<div>\n<style scoped>\n    .dataframe tbody tr th:only-of-type {\n        vertical-align: middle;\n    }\n\n    .dataframe tbody tr th {\n        vertical-align: top;\n    }\n\n    .dataframe thead th {\n        text-align: right;\n    }\n</style>\n<table border=\"1\" class=\"dataframe\">\n  <thead>\n    <tr style=\"text-align: right;\">\n      <th></th>\n      <th>startTime</th>\n      <th>temperature</th>\n      <th>shortForecast</th>\n      <th>Snowfall</th>\n    </tr>\n    <tr>\n      <th>Time</th>\n      <th></th>\n      <th></th>\n      <th></th>\n      <th></th>\n    </tr>\n  </thead>\n  <tbody>\n    <tr>\n      <th>2018-11-26 21:00:00</th>\n      <td>2018-11-26T15:00:00-06:00</td>\n      <td>28</td>\n      <td>Mostly Cloudy</td>\n      <td>0</td>\n    </tr>\n    <tr>\n      <th>2018-11-26 22:00:00</th>\n      <td>2018-11-26T16:00:00-06:00</td>\n      <td>26</td>\n      <td>Mostly Cloudy</td>\n      <td>0</td>\n    </tr>\n    <tr>\n      <th>2018-11-26 23:00:00</th>\n      <td>2018-11-26T17:00:00-06:00</td>\n      <td>24</td>\n      <td>Mostly Cloudy</td>\n      <td>0</td>\n    </tr>\n    <tr>\n      <th>2018-11-27 00:00:00</th>\n      <td>2018-11-26T18:00:00-06:00</td>\n      <td>23</td>\n      <td>Mostly Cloudy</td>\n      <td>0</td>\n    </tr>\n    <tr>\n      <th>2018-11-27 01:00:00</th>\n      <td>2018-11-26T19:00:00-06:00</td>\n      <td>23</td>\n      <td>Mostly Cloudy</td>\n      <td>0</td>\n    </tr>\n  </tbody>\n</table>\n</div>"}︡{"done":true}︡
︠30974e4c-f204-48ec-94da-e891ef570cd0s︠
# plot forecast for temperature and snowfall
# key to snowfall:
#   2 = heavy
#   1 = chance of snow
#   0 = no snow

df[['temperature','Snowfall']].plot(subplots=True, sharex=True, figsize=(6,2.5), fontsize=8);
︡78077c4c-9dd0-4e2d-83e4-a3ff1730dc0c︡{"file":{"filename":"/tmp/tmpPdRiTY.png","show":true,"text":null,"uuid":"46e4ee19-6ad6-406b-a712-b13c1a48fee3"},"once":false}︡{"done":true}︡
︠e4f63064-45a3-4b68-8ce4-dd610b946b8ds︠
︡3e451c09-d21f-40d6-b283-7886f2a4a16a︡{"done":true}︡
︠5fd71eb4-5f4f-4069-b9e4-c24500a0d724︠









